@@ -2,7 +2,7 @@
 
 class API extends Handler {
 
-	const API_LEVEL  = 6;
+	const API_LEVEL  = 9;
 
 	const STATUS_OK  = 0;
 	const STATUS_ERR = 1;
@@ -77,6 +77,7 @@ class API extends Handler {
 				$this->wrap(self::STATUS_OK,	array("session_id" => session_id(),
 					"api_level" => self::API_LEVEL));
 			} else {                                                         // else we are not logged in
+				user_error("Failed login attempt for $login from {$_SERVER['REMOTE_ADDR']}", E_USER_WARNING);
 				$this->wrap(self::STATUS_ERR, array("error" => "LOGIN_ERROR"));
 			}
 		} else {
@@ -197,12 +198,17 @@ class API extends Handler {
 			$include_attachments = sql_bool_to_bool($_REQUEST["include_attachments"]);
 			$since_id = (int)$this->dbh->escape_string($_REQUEST["since_id"]);
 			$include_nested = sql_bool_to_bool($_REQUEST["include_nested"]);
-			$sanitize_content = true;
+			$sanitize_content = !isset($_REQUEST["sanitize"]) ||
+				sql_bool_to_bool($_REQUEST["sanitize"]);
+			$force_update = sql_bool_to_bool($_REQUEST["force_update"]);
 
 			$override_order = false;
 			switch ($_REQUEST["order_by"]) {
+				case "title":
+					$override_order = "ttrss_entries.title";
+					break;
 				case "date_reverse":
-					$override_order = "date_entered, updated";
+					$override_order = "score DESC, date_entered, updated";
 					break;
 				case "feed_dates":
 					$override_order = "updated DESC";
@@ -217,7 +223,7 @@ class API extends Handler {
 			$headlines = $this->api_get_headlines($feed_id, $limit, $offset,
 				$filter, $is_cat, $show_excerpt, $show_content, $view_mode, $override_order,
 				$include_attachments, $since_id, $search, $search_mode,
-				$include_nested, $sanitize_content);
+				$include_nested, $sanitize_content, $force_update);
 
 			$this->wrap(self::STATUS_OK, $headlines);
 		} else {
@@ -306,54 +312,60 @@ class API extends Handler {
 
 		$article_id = join(",", array_filter(explode(",", $this->dbh->escape_string($_REQUEST["article_id"])), is_numeric));
 
-		$query = "SELECT id,title,link,content,cached_content,feed_id,comments,int_id,
-			marked,unread,published,score,
-			".SUBSTRING_FOR_DATE."(updated,1,16) as updated,
-			author,(SELECT title FROM ttrss_feeds WHERE id = feed_id) AS feed_title
-			FROM ttrss_entries,ttrss_user_entries
-			WHERE	id IN ($article_id) AND ref_id = id AND owner_uid = " .
-				$_SESSION["uid"] ;
+		if ($article_id) {
 
-		$result = $this->dbh->query($query);
+			$query = "SELECT id,title,link,content,feed_id,comments,int_id,
+				marked,unread,published,score,note,lang,
+				".SUBSTRING_FOR_DATE."(updated,1,16) as updated,
+				author,(SELECT title FROM ttrss_feeds WHERE id = feed_id) AS feed_title
+				FROM ttrss_entries,ttrss_user_entries
+				WHERE	id IN ($article_id) AND ref_id = id AND owner_uid = " .
+					$_SESSION["uid"] ;
 
-		$articles = array();
+			$result = $this->dbh->query($query);
 
-		if ($this->dbh->num_rows($result) != 0) {
+			$articles = array();
 
-			while ($line = $this->dbh->fetch_assoc($result)) {
+			if ($this->dbh->num_rows($result) != 0) {
 
-				$attachments = get_article_enclosures($line['id']);
+				while ($line = $this->dbh->fetch_assoc($result)) {
 
-				$article = array(
-					"id" => $line["id"],
-					"title" => $line["title"],
-					"link" => $line["link"],
-					"labels" => get_article_labels($line['id']),
-					"unread" => sql_bool_to_bool($line["unread"]),
-					"marked" => sql_bool_to_bool($line["marked"]),
-					"published" => sql_bool_to_bool($line["published"]),
-					"comments" => $line["comments"],
-					"author" => $line["author"],
-					"updated" => (int) strtotime($line["updated"]),
-					"content" => $line["cached_content"] != "" ? $line["cached_content"] : $line["content"],
-					"feed_id" => $line["feed_id"],
-					"attachments" => $attachments,
-					"score" => (int)$line["score"],
-					"feed_title" => $line["feed_title"]
-				);
+					$attachments = get_article_enclosures($line['id']);
+
+					$article = array(
+						"id" => $line["id"],
+						"title" => $line["title"],
+						"link" => $line["link"],
+						"labels" => get_article_labels($line['id']),
+						"unread" => sql_bool_to_bool($line["unread"]),
+						"marked" => sql_bool_to_bool($line["marked"]),
+						"published" => sql_bool_to_bool($line["published"]),
+						"comments" => $line["comments"],
+						"author" => $line["author"],
+						"updated" => (int) strtotime($line["updated"]),
+						"content" => $line["content"],
+						"feed_id" => $line["feed_id"],
+						"attachments" => $attachments,
+						"score" => (int)$line["score"],
+						"feed_title" => $line["feed_title"],
+						"note" => $line["note"],
+						"lang" => $line["lang"]
+					);
+
+					foreach (PluginHost::getInstance()->get_hooks(PluginHost::HOOK_RENDER_ARTICLE_API) as $p) {
+						$article = $p->hook_render_article_api(array("article" => $article));
+					}
+
+
+					array_push($articles, $article);
 
-				foreach (PluginHost::getInstance()->get_hooks(PluginHost::HOOK_RENDER_ARTICLE_API) as $p) {
-					$article = $p->hook_render_article_api(array("article" => $article));
 				}
-
-
-				array_push($articles, $article);
-
 			}
+
+			$this->wrap(self::STATUS_OK, $articles);
+		} else {
+			$this->wrap(self::STATUS_ERR, array("error" => 'INCORRECT_USAGE'));
 		}
-
-		$this->wrap(self::STATUS_OK, $articles);
-
 	}
 
 	function getConfig() {
@@ -418,14 +430,14 @@ class API extends Handler {
 
 			$checked = false;
 			foreach ($article_labels as $al) {
-				if ($al[0] == $line['id']) {
+				if (feed_to_label_id($al[0]) == $line['id']) {
 					$checked = true;
 					break;
 				}
 			}
 
 			array_push($rv, array(
-				"id" => (int)$line['id'],
+				"id" => (int)label_to_feed_id($line['id']),
 				"caption" => $line['caption'],
 				"fg_color" => $line['fg_color'],
 				"bg_color" => $line['bg_color'],
@@ -442,7 +454,7 @@ class API extends Handler {
 		$assign = (bool) $this->dbh->escape_string($_REQUEST['assign']) == "true";
 
 		$label = $this->dbh->escape_string(label_find_caption(
-			$label_id, $_SESSION["uid"]));
+			feed_to_label_id($label_id), $_SESSION["uid"]));
 
 		$num_updated = 0;
 
@@ -506,7 +518,7 @@ class API extends Handler {
 					if ($unread || !$unread_only) {
 
 						$row = array(
-								"id" => $cv["id"],
+								"id" => (int) $cv["id"],
 								"title" => $cv["description"],
 								"unread" => $cv["counter"],
 								"cat_id" => -2,
@@ -552,7 +564,7 @@ class API extends Handler {
 
 					if ($unread || !$unread_only) {
 						$row = array(
-								"id" => $line["id"],
+								"id" => (int) $line["id"],
 								"title" => $line["title"],
 								"unread" => $unread,
 								"is_cat" => true,
@@ -621,7 +633,28 @@ class API extends Handler {
 				$filter, $is_cat, $show_excerpt, $show_content, $view_mode, $order,
 				$include_attachments, $since_id,
 				$search = "", $search_mode = "",
-				$include_nested = false, $sanitize_content = true) {
+				$include_nested = false, $sanitize_content = true, $force_update = false) {
+
+			if ($force_update && $feed_id > 0 && is_numeric($feed_id)) {
+				// Update the feed if required with some basic flood control
+
+				$result = db_query(
+					"SELECT cache_images,".SUBSTRING_FOR_DATE."(last_updated,1,19) AS last_updated
+						FROM ttrss_feeds WHERE id = '$feed_id'");
+
+				if (db_num_rows($result) != 0) {
+					$last_updated = strtotime(db_fetch_result($result, 0, "last_updated"));
+					$cache_images = sql_bool_to_bool(db_fetch_result($result, 0, "cache_images"));
+
+					if (!$cache_images && time() - $last_updated > 120) {
+						include "rssfuncs.php";
+						update_rss_feed($feed_id, true, true);
+					} else {
+						db_query("UPDATE ttrss_feeds SET last_updated = '1970-01-01', last_update_started = '1970-01-01'
+							WHERE id = '$feed_id'");
+					}
+				}
+			}
 
 			$qfh_ret = queryFeedHeadlines($feed_id, $limit,
 				$view_mode, $is_cat, $search, $search_mode,
@@ -633,6 +666,11 @@ class API extends Handler {
 			$headlines = array();
 
 			while ($line = db_fetch_assoc($result)) {
+				$line["content_preview"] = truncate_string(strip_tags($line["content"]), 100);
+				foreach (PluginHost::getInstance()->get_hooks(PluginHost::HOOK_QUERY_HEADLINES) as $p) {
+					$line = $p->hook_query_headlines($line, 100, true);
+				}
+
 				$is_updated = ($line["last_read"] == "" &&
 					($line["unread"] != "t" && $line["unread"] != "1"));
 
@@ -655,28 +693,22 @@ class API extends Handler {
 						"tags" => $tags,
 					);
 
-					if ($include_attachments)
-						$headline_row['attachments'] = get_article_enclosures(
-							$line['id']);
+				if ($include_attachments)
+					$headline_row['attachments'] = get_article_enclosures(
+						$line['id']);
 
-				if ($show_excerpt) {
-					$excerpt = truncate_string(strip_tags($line["content_preview"]), 100);
-					$headline_row["excerpt"] = $excerpt;
-				}
+				if ($show_excerpt)
+					$headline_row["excerpt"] = $line["content_preview"];
 
 				if ($show_content) {
 
-					if ($line["cached_content"] != "") {
-						$line["content_preview"] =& $line["cached_content"];
-					}
-
 					if ($sanitize_content) {
 						$headline_row["content"] = sanitize(
-							$line["content_preview"],
+							$line["content"],
 							sql_bool_to_bool($line['hide_images']),
-							false, $line["site_url"]);
+							false, $line["site_url"], false, $line["id"]);
 					} else {
-						$headline_row["content"] = $line["content_preview"];
+						$headline_row["content"] = $line["content"];
 					}
 				}
 
@@ -694,7 +726,10 @@ class API extends Handler {
 				$headline_row["always_display_attachments"] = sql_bool_to_bool($line["always_display_enclosures"]);
 
 				$headline_row["author"] = $line["author"];
+
 				$headline_row["score"] = (int)$line["score"];
+				$headline_row["note"] = $line["note"];
+				$headline_row["lang"] = $line["lang"];
 
 				foreach (PluginHost::getInstance()->get_hooks(PluginHost::HOOK_RENDER_ARTICLE_API) as $p) {
 					$headline_row = $p->hook_render_article_api(array("headline" => $headline_row));
